(**
  Visualizes the VODrawTest object. The object draws some drawing primites
  together with some test markes to see if the primitives are positioned
  and sized correctly.
**)

MODULE DrawTest;

(*
    Demo for VisualOberon. Checks correctnes of some drawing primitives.
    Copyright (C) 1999  Tim Teulings (rael@edge.ping.de)

    This file is part of VisualOberon.

    VisualOberon is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    VisualOberon is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with VisualOberon. If not, write to the Free Software
    Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*)

IMPORT D   := VODisplay,     (* Display stuff *)
       DT  := VODrawTest,
       G   := VOGUIObject,   (* GUI object baseclass *)
              VOUsePrefs,    (* The use the preferences setting *)
       W   := VOWindow,      (* Window class *)
       WG  := VOWindowGroup, (* The window group object *)

              Err;           (* Simple error IO *)


VAR
  d          : D.Display;      (* The instance display class *)
  w          : W.Window;       (* The window *)

  test       : DT.DrawTest;
  wGroup     : WG.WindowGroup; (* The window group *)

  msg2Exit   : D.Msg2Exit;     (* a simple message converter *)


BEGIN
  (*
    Allocate an instance of the display class,
    you need only one per application
  *)
  NEW(d);

  (*
    Try to initialize it.
    This call make the connection to the X server and allocates
    fonts, colors and that stuff
  *)
  IF ~d.InitDisplay("DrawTest") THEN
    Err.String("Cannot open to display!"); Err.Ln;
    HALT(1);
  END;

  (*
    Allocate an instance of the window group class.
    This group handles positioning of menustrip and window contents.
  *)
  NEW(wGroup);

  (* Every instance must be initialized *)
  wGroup.Init;

    NEW(test);
    test.Init;

  wGroup.Set(NIL,test,TRUE);

  (* Create an instance of the window class *)
  NEW(w);

  (* Initialize it *)
  w.Init;

  (* Assign the display to the window *)
  w.SetDisplay(d);

  (* Set the top object of the window to the window group *)
  w.SetTop(wGroup);

  (* Set the title of the window *)
  w.SetTitle("DrawTest");

  (*
    Allocate an instance of this special message handler.
    A handler is a class that can convert any or a special
    input message to an other message and sends the resulting
    message to the given destination. However the baseclas just
    returns the input message.

    Most converters are handwritten, but some special converters are
    given by the corresponding objects.

    This converter converts the close-message generated when clicking
    the closing gadget of the window to an exist-message of the display
    class.
  *)
    NEW(msg2Exit);

  (*
    Send the resulting exit message to the display, which will finish
    the event loop and receiving.
  *)
  msg2Exit.destination:=d;

  (*
    Add the handler to window and tell the window that it should call
    this hndler when a close message gets send.
  *)
  w.AddHandler(msg2Exit,W.closeMsg);

  (* Open the main window *)
  w.Open;

  (*
    Start the main event loop. The event loop will get finished when
    the display receives a close message or its exit method gets called.
  *)
  d.Handler;

  (* Free possible ressources of the display. *)
  d.Deinit;
END DrawTest.